@@ -25,6 +25,8 @@ extensions = [
     'openstackdocstheme',
     'oslo_config.sphinxext',
     'oslo_config.sphinxconfiggen',
+    'oslo_policy.sphinxext',
+    'oslo_policy.sphinxpolicygen',
 ]
 
 # openstackdocstheme options
@@ -89,7 +91,7 @@ _config_generator_config_files = [
     'bgp_dragent.ini',
 ]
 
-def _get_config_generator_config_definition(config_file):
+def _get_config_generator_config_definition(conf):
     config_file_path = '../../etc/oslo-config-generator/%s' % conf
     # oslo_config.sphinxconfiggen appends '.conf.sample' to the filename,
     # strip file extentension (.conf or .ini).
@@ -101,3 +103,8 @@ config_generator_config_file = [
     _get_config_generator_config_definition(conf)
     for conf in _config_generator_config_files
 ]
+
+# -- Options for oslo_policy.sphinxpolicygen ---------------------------------
+
+policy_generator_config_file = '../../etc/oslo-policy-generator/policy.conf'
+sample_policy_basename = '_static/neutron-dynamic-routing'
