@@ -14,18 +14,18 @@
 
 from netaddr import IPAddress
 
+from neutron_lib.api.definitions import portbindings
 from neutron_lib.callbacks import events
 from neutron_lib.callbacks import registry
 from neutron_lib.callbacks import resources
 from neutron_lib import constants as n_const
 from neutron_lib import context
+from neutron_lib import rpc as n_rpc
 from neutron_lib.services import base as service_base
 from oslo_config import cfg
 from oslo_log import log as logging
 from oslo_utils import importutils
 
-from neutron.common import rpc as n_rpc
-
 from neutron_dynamic_routing.api.rpc.agentnotifiers import bgp_dr_rpc_agent_api  # noqa
 from neutron_dynamic_routing.api.rpc.callbacks import resources as dr_resources
 from neutron_dynamic_routing.api.rpc.handlers import bgp_speaker_rpc as bs_rpc
@@ -56,9 +56,6 @@ class BgpPlugin(service_base.ServicePluginBase,
         self._register_callbacks()
         self.add_periodic_dragent_status_check()
 
-    def get_plugin_name(self):
-        return PLUGIN_NAME
-
     def get_plugin_type(self):
         return bgp_ext.BGP_EXT_ALIAS
 
@@ -69,7 +66,7 @@ class BgpPlugin(service_base.ServicePluginBase,
 
     def _setup_rpc(self):
         self.topic = bgp_consts.BGP_PLUGIN
-        self.conn = n_rpc.create_connection()
+        self.conn = n_rpc.Connection()
         self.agent_notifiers[bgp_consts.AGENT_TYPE_BGP_ROUTING] = (
             bgp_dr_rpc_agent_api.BgpDrAgentNotifyApi()
         )
@@ -98,6 +95,9 @@ class BgpPlugin(service_base.ServicePluginBase,
         registry.subscribe(self.router_gateway_callback,
                            resources.ROUTER_GATEWAY,
                            events.AFTER_DELETE)
+        registry.subscribe(self.port_callback,
+                           resources.PORT,
+                           events.AFTER_UPDATE)
 
     def get_bgp_speakers(self, context, filters=None, fields=None,
                          sorts=None, limit=None, marker=None,
@@ -347,6 +347,36 @@ class BgpPlugin(service_base.ServicePluginBase,
                 self.stop_route_advertisements(ctx, self._bgp_rpc,
                                                speaker.id, routes)
 
+    def port_callback(self, resource, event, trigger, **kwargs):
+        if event != events.AFTER_UPDATE:
+            return
+
+        original_port = kwargs['original_port']
+        updated_port = kwargs['port']
+        if not updated_port.get('fixed_ips'):
+            return
+
+        original_host = original_port.get(portbindings.HOST_ID)
+        updated_host = updated_port.get(portbindings.HOST_ID)
+        device_owner = updated_port.get('device_owner')
+
+        # if host in the port binding has changed, update next-hops
+        if original_host != updated_host and bool('compute:' in device_owner):
+            ctx = context.get_admin_context()
+            with ctx.session.begin(subtransactions=True):
+                ext_nets = self.get_external_networks_for_port(ctx,
+                                                               updated_port)
+                for ext_net in ext_nets:
+                    bgp_speakers = (
+                        self._get_bgp_speaker_ids_by_binding_network(
+                            ctx, ext_nets))
+
+                    # Refresh any affected BGP speakers
+                    for bgp_speaker in bgp_speakers:
+                        routes = self.get_advertised_routes(ctx, bgp_speaker)
+                        self.start_route_advertisements(ctx, self._bgp_rpc,
+                                                        bgp_speaker, routes)
+
     def _next_hops_from_gateway_ips(self, gw_ips):
         if gw_ips:
             return {IPAddress(ip).version: ip for ip in gw_ips}
